@@ -1,5 +1,5 @@
 /* 
- -copyright-
+   -copyright-
 # xsnow: let it snow on your desktop
 # Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
 #              2019,2020,2021,2022,2023,2024 Willem Vermin
@@ -27,10 +27,13 @@
 #include <assert.h>
 #include "transwindow.h"
 #include "windows.h"
+#include "wmctrl.h"
 #include "debug.h"
+#include "xdo.h"
 
 
 static int setvaria(GtkWidget *widget);
+static int GetYOffset(Display *mydisplay, int x, int y, int w, int h);
 
 /*
  * creates transparent window using gtk3/cairo. 
@@ -50,7 +53,7 @@ static int setvaria(GtkWidget *widget);
 int make_trans_window(Display *display, GtkWidget *transwindow, int xscreen, int sticky, int below, int dock,  
       GdkWindow **gdk_window, Window *x11_window, int *wantx, int *wanty)
 {
-   P("Entering make_trans_window...\n");
+   P("Entering make_trans_window... wantx: %d wanty: %d\n",*wantx, *wanty);
    if(gdk_window)
       *gdk_window = NULL;
    if(x11_window)
@@ -107,75 +110,147 @@ int make_trans_window(Display *display, GtkWidget *transwindow, int xscreen, int
    int wantxin = (xscreen >=0);
    // set full screen if so desired:
    P("xscreen: %d\n",xscreen);
+
    if(xscreen < 0)
    {
       P("fullscreen\n");
       XWindowAttributes attr;
       XGetWindowAttributes(display,DefaultRootWindow(display),&attr);
       P("width, height %d %d\n",attr.width,attr.height);
-      gtk_widget_set_size_request(GTK_WIDGET(transwindow),attr.width,attr.height);
       winx = 0;
       winy = 0;
       winw = attr.width;
-      winh = attr.height;
+      int x,y,w,h,yoffset;
+      int nscreens = xinerama(display, -1, &x, &y, &w, &h);
+      if (nscreens == 0)
+      {
+	 yoffset = GetYOffset(display,0,0,w,10);
+	 P("nscreens = 0, yoffset: %d\n",yoffset);
+      }
+      else
+      {
+	 yoffset = 0;
+	 for (int screen=0; screen<nscreens; screen++)
+	 {
+	    xinerama(display,screen, &x, &y, &w, &h);
+	    int q = GetYOffset(display,x,y,w,10);
+	    if (q > yoffset)
+	    {
+	       yoffset = q;
+	       P("yoffset %d, x %d, y %d,w %d,h %d\n",yoffset,x,y,w,h);
+	    }
+	 }
+      }
+      winh = attr.height-yoffset;
+      P("GetYOffset: %d\n",yoffset);
+      gtk_widget_set_size_request(GTK_WIDGET(transwindow),winw,winh);
+
    }
-   else
+   else  // xscreen >= 0
    {
       P("NOT fullscreen, but xineramascreen %d\n",xscreen);
       wantxin = xinerama(display,xscreen,&winx,&winy,&winw,&winh);
+      int yoffset = GetYOffset(display,winx,winy,winw,10) - winy;
+      P("yoffset: %d %d %d wantxin: %d\n",yoffset,winx,winy,wantxin);
+      winh -= yoffset;
+      P("winh: %d\n",winh);
       if(wantxin)
       {
-	 gtk_widget_set_size_request(GTK_WIDGET(transwindow),winw,winh);
 	 P("winx ... %d %d %d %d\n",winx,winy,winw,winh);
+	 gtk_widget_set_size_request(GTK_WIDGET(transwindow),winw,winh);
       }
    }
 
    gtk_widget_show_all(transwindow);
    GdkWindow *gdkwin = gtk_widget_get_window(GTK_WIDGET(transwindow));
 
+
    // so that apps like xsnow will ignore this window:
    if(dock)
       gdk_window_set_type_hint(gdkwin,GDK_WINDOW_TYPE_HINT_DOCK);
+   else
+      gdk_window_set_type_hint(gdkwin,GDK_WINDOW_TYPE_HINT_NORMAL);
 
-   //gdk_window_hide(gdkwin);
+   gdk_window_hide(gdkwin);
 
    gdk_window_show(gdkwin);
 
    if (x11_window)
    {
       *x11_window = gdk_x11_window_get_xid(gdkwin);
+
       P("resize %p: %d %d\n",(void*)*x11_window,winw,winh);
       XResizeWindow(display,*x11_window,winw,winh);  // necessary in xmonad, don't know why, 
       XFlush(display);                               // in combination with this one
+
+      if (gdk_window)
+	 *gdk_window = gdkwin;
+
+      *wantx = winx;
+      *wanty = winy;
+      usleep(200000);  // seems sometimes to be necessary with nvidia
+
+      // just to be sure all settings are communicated with the server
+      gtk_widget_hide(transwindow);
+      gtk_widget_show_all(transwindow);
+      if(xscreen < 0)
+      {
+	 P("Calling gtk_window_move %d %d\n",winx,winy);
+	 gtk_window_move(GTK_WINDOW(transwindow),0,0);
+      }
+      else if (wantxin)
+      {
+	 P("Calling gtk_window_move %d %d\n",winx,winy);
+	 gtk_window_move(GTK_WINDOW(transwindow),winx,winy);
+      }
+      gtk_widget_show_all(transwindow);
+
+      // set some things, but note that this has to be repeated in the gkt_main loop.
+
+      P("explicitly call setvaria\n");
+      setvaria(transwindow);
+      P("end explicit call\n");
+      g_object_steal_data(G_OBJECT(transwindow),"trans_done");
+
    }
-   if (gdk_window)
-      *gdk_window = gdkwin;
-
-   *wantx = winx;
-   *wanty = winy;
-   usleep(200000);  // seems sometimes to be necessary with nvidia
-
-   // just to be sure all settings are communicated with the server
-   gtk_widget_hide(transwindow);
-   gtk_widget_show_all(transwindow);
-   if(xscreen < 0)
-      gtk_window_move(GTK_WINDOW(transwindow),0,0);
-   else if (wantxin)
-   {
-      P("Calling gtk_window_move %d %d\n",winx,winy);
-      gtk_window_move(GTK_WINDOW(transwindow),winx,winy);
-   }
-
-   // set some things, but note that this has to be repeated in the gkt_main loop.
-
-   P("explicitly call setvaria\n");
-   setvaria(transwindow);
-   P("end explicit call\n");
-   g_object_steal_data(G_OBJECT(transwindow),"trans_done");
-
    return TRUE;
 }
 
+// GetYOffset() returns the absolute y coordinate of a window placed at x,y.
+// Method: create a window at x,y and use XTranslateCoordinates() to get the 
+// desired value.
+int GetYOffset(Display *mydisplay, int x, int y, int w, int h)
+{
+   Window mywindow = XCreateSimpleWindow(mydisplay,DefaultRootWindow(mydisplay),
+	 x,y,w,h,
+	 0,              // border width
+	 0UL,            // valuemask
+			 // 0xffff00UL      // background color yellow
+	 0UL             // background black
+	 );
+
+   // make sure that window is indeed placed at x,y and indeed has size w,h:
+   XSizeHints wmsize;
+   wmsize.flags = USPosition | USSize;
+   XSetWMNormalHints ( mydisplay , mywindow , &wmsize ) ;
+
+   // remove decorations:
+   long hints[5] = {2 , 0, 0, 0, 0};
+   Atom motif_hints = XInternAtom(mydisplay, "_MOTIF_WM_HINTS", False);
+   XChangeProperty(mydisplay, mywindow, motif_hints, motif_hints, 32, PropModeReplace, (unsigned char *)&hints, 5);
+
+   XMapWindow(mydisplay, mywindow);
+   xdo_t *xdo = xdo_new_with_opened_display(mydisplay,NULL,0);
+   xdo_wait_for_window_map_state(xdo,mywindow,IsViewable);
+
+   int returnvalue;
+   GetAbsoluteCoordinates(mydisplay, mywindow, NULL, &returnvalue, NULL, NULL);
+   //  sleep(5);
+
+   xdo_free(xdo);
+   XDestroyWindow(mydisplay, mywindow);
+   return returnvalue;
+}
 
 // for some reason, in some environments the 'below' and 'stick' properties
 // disappear. It works again, if we express our wishes after starting gtk_main
@@ -188,7 +263,7 @@ int setvaria(GtkWidget *widget)
    // Use the value of p itself, not what it points to.
    // Following the C standard, we have to use an array to subtract pointers.
    enum {rep = 1,nrep}; // must be >= 0, and is equal to the number of times the settings
-   //                      will be done when called more than once
+			//                      will be done when called more than once
    static char something[nrep];
    char *p = (char *)g_object_get_data(G_OBJECT(widget),"trans_done");
    if (!p)
