@@ -1,5 +1,5 @@
 /* 
- -copyright-
+   -copyright-
 # xsnow: let it snow on your desktop
 # Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
 #              2019,2020,2021,2022,2023,2024 Willem Vermin
@@ -80,8 +80,7 @@ int WorkspaceActive()
    // ah, so difficult ...
    if (Flags.AllWorkspaces)
       return 1;
-   int i;
-   for (i=0; i<global.NVisWorkSpaces; i++)
+   for (int i=0; i<global.NVisWorkSpaces; i++)
    {
       if (global.VisWorkSpaces[i] == global.ChosenWorkSpace)
 	 return 1;
@@ -112,7 +111,7 @@ int do_sendevent(void *dummy)
 int do_wupdate(void *dummy)
 {
    static long PrevWorkSpace = -123;
-   P("do_wupdate %d %d\n",counter++,global.WindowsChanged);
+   P("do_wupdate #%d %d\n",global.counter++,global.WindowsChanged);
    if (Flags.Done)
       return FALSE;
 
@@ -160,7 +159,8 @@ int do_wupdate(void *dummy)
 
    P("Update windows\n");
 
-   if(Windows) free(Windows);
+   if(Windows) 
+      free(Windows);
 
    // special hack too keep global.SnowWin below (needed for example in FVWM/xcompmgr, 
    // where global.SnowWin is not click-through)
@@ -181,8 +181,7 @@ int do_wupdate(void *dummy)
       goto end;
    }
 
-   int i;
-   for (i=0; i<NWindows; i++)
+   for (int i=0; i<NWindows; i++)
    {
       WinInfo *w = &Windows[i];
       P("SnowWinX SnowWinY: %d %d\n",global.SnowWinX,global.SnowWinY);
@@ -297,9 +296,8 @@ void DetermineVisualWorkspaces()
    xdo_map_window(global.xdo,ProbeWindow);
 
    global.NVisWorkSpaces = number;
-   int i;
    int prev = -SOMENUMBER;
-   for (i=0; i<number; i++)
+   for (int i=0; i<number; i++)
    {
       int x = info[i].x_org;
       int y = info[i].y_org;
@@ -350,10 +348,9 @@ void UpdateFallenSnowRegions()
    // threads: locking by caller
    WinInfo *w;
    FallenSnow *fsnow;
-   int i;
    // add fallensnow regions:
    w = Windows;
-   for (i=0; i<NWindows; i++)
+   for (int i=0; i<NWindows; i++)
    {
       //P("%d %#lx\n",i,w->id);
       {
@@ -374,12 +371,15 @@ void UpdateFallenSnowRegions()
 	    // add it, but not if we are snowing or birding in this window (Desktop for example)
 	    // and also not if this window has y <= 0
 	    // and also not if this window is a "dock"
-	    P("               %#lx %d\n",w->id,w->dock);
-	    if (w->id != global.SnowWin && w->y > 0 && !(w->dock)) 
+	    // and also not if this window is "hidden"
+	    // and also not if this window is to be ignored
+	    P("               %#lx %d %d %d\n",w->id,w->dock,w->w,w->ignore);
+	    if (w->id != global.SnowWin && w->y > 0 && !(w->dock) && !(w->hidden) && !(w->ignore)) 
 	    {
+	       P("dock? %#lx %d %d %d\n",w->id,w->dock,w->hidden,w->w);
 	       if(((int)(w->w) == global.SnowWinWidth && w->x == 0 && w->y <100)) //maybe a transparent xpenguins window?
 	       {
-		  P("skipping: %d %#lx %d %d %d\n",global.counter++, w->id, w->w, w->x, w->y);
+		  P("skipping: #%d %#lx %d %d %d\n",global.counter++, w->id, w->w, w->x, w->y);
 	       }
 	       else
 	       {
@@ -420,7 +420,7 @@ void UpdateFallenSnowRegions()
 	   )
 	 {
 	    P("Gone...\n");
-	    GenerateFlakesFromFallen(fsnow,0,fsnow->w,-10.0);
+	    GenerateFlakesFromFallen(fsnow,0,fsnow->w,-10.0,0.15,1);
 	    toremove[ntoremove++] = fsnow->win.id;
 	 }
 
@@ -433,7 +433,7 @@ void UpdateFallenSnowRegions()
 	    P("%#lx is hidden %d\n",fsnow->win.id, global.counter++);
 	    if(global.DoCapella)
 	    {
-	       GenerateFlakesFromFallen(fsnow,0,fsnow->w,-10.0);
+	       GenerateFlakesFromFallen(fsnow,0,fsnow->w,-10.0,0.15,1);
 	       toremove[ntoremove++] = fsnow->win.id;
 	    }
 	    else
@@ -450,7 +450,7 @@ void UpdateFallenSnowRegions()
    // moved: move fallen area accordingly
    // resized: remove fallen area: add it to toremove
    w = Windows;
-   for(i=0; i<NWindows; i++)
+   for (int i=0; i<NWindows; i++)
    {
       fsnow = FindFallen(global.FsnowFirst,w->id);
       if (fsnow)
@@ -461,7 +461,7 @@ void UpdateFallenSnowRegions()
 	    {
 	       if (global.DoCapella)
 	       {
-		  GenerateFlakesFromFallen(fsnow,0,fsnow->w,-10.0);
+		  GenerateFlakesFromFallen(fsnow,0,fsnow->w,-10.0,0.15,1);
 		  toremove[ntoremove++] = fsnow->win.id;
 	       }
 	       else
@@ -477,14 +477,14 @@ void UpdateFallenSnowRegions()
 	 else
 	 {
 	    if(global.DoCapella)
-	       GenerateFlakesFromFallen(fsnow,0,fsnow->w,-10.0);
+	       GenerateFlakesFromFallen(fsnow,0,fsnow->w,-10.0,0.15,1);
 	    toremove[ntoremove++] = fsnow->win.id;
 	 }
       }
       w++;
    }
 
-   for (i=0; i<ntoremove; i++)
+   for (int i=0; i<ntoremove; i++)
    {
       CleanFallen(toremove[i]);
       RemoveFallenSnow(&global.FsnowFirst,toremove[i]);
@@ -520,7 +520,7 @@ int xinerama(Display *display, int xscreen, int *x, int *y, int *w, int *h)
    if (info == NULL)
    {
       I("No xinerama...\n");
-      return FALSE;
+      return 0;
    }
    else
    {
@@ -528,8 +528,7 @@ int xinerama(Display *display, int xscreen, int *x, int *y, int *w, int *h)
       if(scr > number-1)
 	 scr = number-1;
 
-      int i;
-      for (i=0; i<number; i++)
+      for (int i=0; i<number; i++)
       {
 	 P("number: %d\n",info[i].screen_number);
 	 P("   x_org:  %d\n",info[i].x_org);
@@ -542,26 +541,32 @@ int xinerama(Display *display, int xscreen, int *x, int *y, int *w, int *h)
       {
 	 // set x,y to 0,0
 	 // set width and height to maximum values found
-	 int i;
-	 *x = 0;
-	 *y = 0;
-	 *w = 0;
-	 *h = 0;
-	 for (i=0; i<number; i++)
+	 if(x)
+	    *x = 0;
+	 if(y)
+	    *y = 0;
+	 if(w)
+	    *w = 0;
+	 if(h)
+	    *h = 0;
+	 for (int i=0; i<number; i++)
 	 {
-	    if (info[i].width > *w)
+	    if (w && info[i].width > *w)
 	       *w = info[i].width;
-	    if (info[i].height > *h)
+	    if (h && info[i].height > *h)
 	       *h = info[i].height;
 	 }
       }
       else
       {
-
-	 *x = info[scr].x_org;
-	 *y = info[scr].y_org;
-	 *w = info[scr].width;
-	 *h = info[scr].height;
+	 if(x)
+	    *x = info[scr].x_org;
+	 if(y)
+	    *y = info[scr].y_org;
+	 if(w)
+	    *w = info[scr].width;
+	 if(h)
+	    *h = info[scr].height;
       }
       P("Xinerama window: %d+%d %dx%d\n",*x,*y,*w,*h);
 
@@ -595,8 +600,6 @@ void DisplayDimensions()
    int x,y;
    Window root;
 
-   xdo_wait_for_window_map_state(global.xdo,global.SnowWin,IsViewable);
-
    int rc = XGetGeometry(global.display,global.SnowWin,&root, &x, &y, &w, &h, &b, &d); 
 
    if (rc == 0)
@@ -657,11 +660,10 @@ void SetBackground()
 
    int rowstride = gdk_pixbuf_get_rowstride (pixbuf);
    P("rowstride: %d\n",rowstride);
-   int i,j;
    int k = 0;
    if(is_little_endian())
-      for (i=0; i<h; i++)
-	 for(j=0; j<w; j++)
+      for (int i=0; i<h; i++)
+	 for (int j=0; j<w; j++)
 	 {
 	    guchar *p = &pixels[i*rowstride +j*n_channels];
 	    pixels1[k++] = p[2];
@@ -673,8 +675,8 @@ void SetBackground()
    {
       I("Big endian system, swapping bytes in background.\n");
       I("Let me know if this is not OK.\n");
-      for (i=0; i<h; i++)
-	 for(j=0; j<w; j++)
+      for (int i=0; i<h; i++)
+	 for (int j=0; j<w; j++)
 	 {
 	    guchar *p = &pixels[i*rowstride +j*n_channels];
 	    pixels1[k++] = 0xff;
@@ -712,3 +714,18 @@ void SetBackground()
    //free(pixels1);  //This is already freed by XDestroyImage
    return;
 }
+
+// add property with name and value
+int SetProperty(Display *display, Window window, const char *name, const char *value)
+{
+   return XChangeProperty(
+	 display,
+	 window,
+	 XInternAtom(display, name, False),      // property
+	 XInternAtom(display, "STRING", False),  // type
+	 8,                                      // format
+	 PropModeReplace,                        // mode
+	 (unsigned char*)value,                  // data
+	 strlen(value)                           // nelements
+	 );
+}
